intelmq.bots.parsers.malwareurl package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.parsers.malwareurl package

## Submodules

## intelmq.bots.parsers.malwareurl.parser module

`intelmq.bots.parsers.malwareurl.parser.` `BOT`

  alias of `intelmq.bots.parsers.malwareurl.parser.MalwareurlParserBot`

class `intelmq.bots.parsers.malwareurl.parser.` `MalwareurlParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Parse the MalwareURL feed

  `process`()

class `intelmq.bots.parsers.malwareurl.parser.` `MyHTMLParser`(*, convert_charrefs=True)

  Bases: `html.parser.HTMLParser`

  `handle_data`(data)
  `handle_starttag`(tag, attrs)
  `lsData` = ''
  `lsTag` = ''
  `lsValue` = ''

## Module contents